# python_CINI_selector

This repository that build and is the standard CINI selector for differrent use. It is not a package but it is useful to use it in different python projects.

## Instalation

Once activate your python environment. use as standard pip installation: 

````
pip install CINI-selector
````
